@@ -33,8 +33,10 @@
 import os.path
 import traceback
 from collections import OrderedDict
+from collections.abc import Callable, Iterator
 from os import listdir
-from typing import Any, Callable, Dict, Iterator, List, Match, Optional, Pattern
+from re import Match, Pattern
+from typing import Any
 
 from univention.config_registry import ucr
 from univention.lib.i18n import Translation
@@ -52,7 +54,7 @@ _ = Translation('univention-management-console-module-diagnostic').translate
 class Problem(Exception):
 
     def __init__(self, description: str = "", **kwargs: Any) -> None:
-        super(Problem, self).__init__(description)
+        super().__init__(description)
         self.kwargs = kwargs
         kwargs['type'] = self.__class__.__name__.lower()
         if description:
@@ -85,7 +87,7 @@ class Instance(Base, ProgressMixin):
     PLUGIN_DIR = os.path.dirname(plugins.__file__)
 
     def init(self) -> None:
-        self.modules: Dict[str, "Plugin"] = {}
+        self.modules: dict[str, "Plugin"] = {}
         self.load()
 
     @sanitize(
@@ -103,13 +105,13 @@ class Instance(Base, ProgressMixin):
         return plug.execute(self, **args)
 
     def new_progress(self, *args: Any, **kwargs: Any) -> Any:
-        progress = super(Instance, self).new_progress(*args, **kwargs)
+        progress = super().new_progress(*args, **kwargs)
         progress.retry_after = 600
         return progress
 
     @sanitize(pattern=PatternSanitizer(default='.*'))
     @simple_response
-    def query(self, pattern: Pattern[str]) -> List[Dict[str, Any]]:
+    def query(self, pattern: Pattern[str]) -> list[dict[str, Any]]:
         return [plugin.dict for plugin in self if plugin.match(pattern)]
 
     @property
@@ -138,8 +140,8 @@ class Instance(Base, ProgressMixin):
         return iter(self.modules.values())
 
 
-class Plugin(object):
-    u"""
+class Plugin:
+    """
     A wrapper for a Python module underneath of "univention.management.console.modules.diagnostic.plugins".
 
     These Python modules (plugins) may have the following properties:
@@ -219,41 +221,41 @@ class Plugin(object):
 
     @property
     def title(self) -> str:
-        u"""A title for the problem"""
+        """A title for the problem"""
         return getattr(self.module, 'title', '')
 
     @property
     def description(self) -> str:
-        u"""A description of the problem and how to solve it"""
+        """A description of the problem and how to solve it"""
         return getattr(self.module, 'description', '')
 
     @property
-    def buttons(self) -> List[Dict[str, str]]:
-        u"""Buttons which are displayed e.g. to automatically solve the problem"""
+    def buttons(self) -> list[dict[str, str]]:
+        """Buttons which are displayed e.g. to automatically solve the problem"""
         return list(getattr(self.module, 'buttons', []))
 
     @property
-    def run_descr(self) -> List[str]:
+    def run_descr(self) -> list[str]:
         return list(getattr(self.module, 'run_descr', []))
 
     @property
-    def umc_modules(self) -> List[Dict[str, Any]]:
-        u"""
+    def umc_modules(self) -> list[dict[str, Any]]:
+        """
         References to UMC modules which can help solving the problem.
         (module, flavor, properties)
         """
         return getattr(self.module, 'umc_modules', [])
 
     @property
-    def links(self) -> List[Dict[str, str]]:
-        u"""
+    def links(self) -> list[dict[str, str]]:
+        """
         Links to e.g. related SDB articles
         (url, link_name)
         """
         return getattr(self.module, 'links', [])
 
     @property
-    def actions(self) -> Dict[str, Callable[[Instance], Optional[Dict[str, Any]]]]:
+    def actions(self) -> dict[str, Callable[[Instance], dict[str, Any] | None]]:
         return getattr(self.module, 'actions', {})
 
     def __init__(self, plugin: str) -> None:
@@ -267,9 +269,9 @@ class Plugin(object):
             level=0,
         )
 
-    def execute(self, umc_module: Instance, action=None, **kwargs: Any) -> Dict[str, Any]:
+    def execute(self, umc_module: Instance, action=None, **kwargs: Any) -> dict[str, Any]:
         success = True
-        errors: Dict[str, Any] = {}
+        errors: dict[str, Any] = {}
         execute = self.actions.get(action, self.module.run)
         try:
             try:
@@ -284,7 +286,7 @@ class Plugin(object):
             success = False
             errors.update(exc.kwargs)
 
-        result: Dict[str, Any] = {
+        result: dict[str, Any] = {
             "success": success,
             "type": 'success',
         }
@@ -293,14 +295,14 @@ class Plugin(object):
         result.setdefault('buttons', []).insert(0, {'label': _('Test again')})
         return result
 
-    def match(self, pattern: Pattern[str]) -> Optional[Match]:
+    def match(self, pattern: Pattern[str]) -> Match | None:
         return pattern.match(self.title) or pattern.match(self.description)
 
     def __str__(self) -> str:
         return '%s' % (self.plugin,)
 
     @property
-    def dict(self) -> Dict[str, Any]:
+    def dict(self) -> dict[str, Any]:
         return {
             "id": str(self),
             "plugin": str(self),
