@@ -31,10 +31,10 @@
 # <https://www.gnu.org/licenses/>.
 
 import glob
-import socket
 from base64 import b64decode
+from collections.abc import Callable, Iterator
 from subprocess import call
-from typing import Any, Callable, Dict, Iterator, List, Tuple
+from typing import Any
 
 import requests
 from cryptography import x509
@@ -58,28 +58,25 @@ run_descr = ['Checks SAML certificates']
 
 
 def run(_umc_instance: Instance, rerun: bool = False) -> None:
-    keycloak_fqdn = '%s%s' % (
-        ucr.get('keycloak/server/sso/fqdn', 'ucs-sso-ng.%s' % ucr['domainname']),
-        ucr.get('keycloak/server/sso/path', ''),
-    )
-    sso_fqdn = ucr.get('ucs/server/sso/fqdn')
     umc_saml_idp = ucr.get('umc/saml/idp-server', '')
+    if not umc_saml_idp:
+        # SSO not configured
+        return
+
+    keycloak_uri = ucr.get('ucs/server/sso/uri', 'https://ucs-sso-ng.%s' % ucr['domainname'])
     # keycloak
-    if keycloak_fqdn and 'realms/ucs/protocol/saml/descriptor' in umc_saml_idp:
-        run_keycloak(_umc_instance, keycloak_fqdn, rerun)
-    # simplesaml -> can be removed in 5.2
-    elif sso_fqdn:
-        run_simplesamlphp(_umc_instance, sso_fqdn, rerun)
+    if keycloak_uri and 'realms/ucs/protocol/saml/descriptor' in umc_saml_idp:
+        run_keycloak(_umc_instance, keycloak_uri, rerun)
 
 
-def run_keycloak(_umc_instance: Instance, sso_fqdn: str, rerun: bool = False) -> None:
-    problems: List[str] = []
-    buttons: List[Dict[str, str]] = []
-    links: List[Dict[str, str]] = []
-    umc_modules: List[Dict[str, str]] = []
+def run_keycloak(_umc_instance: Instance, sso_uri: str, rerun: bool = False) -> None:
+    problems: list[str] = []
+    buttons: list[dict[str, str]] = []
+    links: list[dict[str, str]] = []
+    umc_modules: list[dict[str, str]] = []
 
     idp = False
-    for problem in test_identity_provider_certificate_keycloak(sso_fqdn):
+    for problem in test_identity_provider_certificate_keycloak(sso_uri):
         idp = True
         kwargs = problem.kwargs
         problems.append(kwargs["description"])
@@ -111,20 +108,20 @@ def run_keycloak(_umc_instance: Instance, sso_fqdn: str, rerun: bool = False) ->
         )
 
 
-def test_identity_provider_certificate_keycloak(sso_fqdn: str) -> Iterator[Problem]:
+def test_identity_provider_certificate_keycloak(sso_uri: str) -> Iterator[Problem]:
     """
     Check that all IDP certificates from :file:`/usr/share/univention-management-console/saml/idp/*.xml`
-    are included in :url:`https:/$(ucr get ucs/server/sso/fqdn)/simplesamlphp/saml2/idp/certificate`.
+    are included in Keycloak.
 
     Fix: ``univention-run-join-scripts --force --run-scripts 92univention-management-console-web-server``
     """
-    MODULE.process("Checks sso certificate by comparing 'ucr get keycloak/server/sso/fqdn' with the Location field in %s" % (XML,))
+    MODULE.process("Checks sso certificate by comparing 'ucr get ucs/server/sso/uri' FQDN with the Location field in %s" % (XML,))
 
     backend = default_backend()
     certificate = None
     data = None
 
-    url = "https://%s/realms/ucs/protocol/saml/descriptor" % (sso_fqdn,)
+    url = "%s/realms/ucs/protocol/saml/descriptor" % (sso_uri,)
     links = {
         "name": 'idp',
         "href": url,
@@ -192,157 +189,6 @@ def test_identity_provider_certificate_keycloak(sso_fqdn: str) -> Iterator[Probl
                 )
 
 
-def run_simplesamlphp(_umc_instance: Instance, sso_fqdn: str, rerun: bool = False) -> None:
-    problems: List[str] = []
-    buttons: List[Dict[str, str]] = []
-    links: List[Dict[str, str]] = []
-    umc_modules: List[Dict[str, str]] = []
-
-    idp = False
-    for problem in test_identity_provider_certificate(sso_fqdn):
-        idp = True
-        kwargs = problem.kwargs
-        problems.append(kwargs["description"])
-        buttons += kwargs.get("buttons", [])
-        links += kwargs.get("links", [])
-        umc_modules += kwargs.get("umc_modules", [])
-
-    if idp and not rerun:
-        problems.append(_(
-            "Re-execute the join-script <tt>92univention-management-console-web-server</tt> via {join} "
-            "or execute <tt>univention-run-join-scripts --force --run-scripts 92univention-management-console-web-server</tt> on the command line as user <i>root</i>.",
-        ))
-        buttons.append({
-            "action": "fix_idp",
-            "label": _("Re-run join script"),
-        })
-        umc_modules.append({
-            "module": "join",
-            # /univention/command/join/run
-            # {"options":{"scripts":["92univention-management-console-web-server"],"force":true}}
-        })
-
-    sp = False
-    for problem in test_service_provider_certificate():
-        sp = True
-        kwargs = problem.kwargs
-        problems.append(kwargs["description"])
-        buttons += kwargs.get("buttons", [])
-        links += kwargs.get("links", [])
-        umc_modules += kwargs.get("umc_modules", [])
-
-    if sp:
-        problems.append(_(
-            "If you renewed your certificates please see {sdb-one} and {sdb-all} for more instructions. "
-            "In that case the new certificate must be re-uploaded into LDAP.",
-        ))
-        links += [
-            {
-                "name": "sdb-one",
-                "href": "https://help.univention.com/t/renewing-the-ssl-certificates/37",
-                        "label": _("Univention Support Database - Renewing the TLS/SSL certificates"),
-            },
-            {
-                "name": "sdb-all",
-                "href": "https://help.univention.com/t/renewing-the-complete-ssl-certificate-chain/36",
-                        "label": _("Univention Support Database - Renewing the complete TLS/SSL certificate chain"),
-            },
-        ]
-        if not rerun:
-            buttons.append({
-                "action": "fix_sp",
-                "label": _("Re-upload certificate"),
-            })
-
-    if problems:
-        raise Critical(
-            description="\n".join(problems),
-            buttons=buttons,
-            links=links,
-            umc_modules=umc_modules,
-        )
-
-
-def test_identity_provider_certificate(sso_fqdn: str) -> Iterator[Problem]:
-    """
-    Check that all IDP certificates from :file:`/usr/share/univention-management-console/saml/idp/*.xml`
-    are included in :url:`https:/$(ucr get ucs/server/sso/fqdn)/simplesamlphp/saml2/idp/certificate`.
-
-    Fix: ``univention-run-join-scripts --force --run-scripts 92univention-management-console-web-server``
-    """
-    MODULE.process("Checks ucs-sso by comparing 'ucr get ucs/server/sso/fqdn' with the Location field in %s" % (XML,))
-
-    backend = default_backend()
-
-    # download from FQDN and all ip addresses of ucs-sso the IDP certificate (/etc/simplesamlphp/*-idp-certificate.crt)
-    _name, _aliaslist, addresslist = socket.gethostbyname_ex(sso_fqdn)
-    for i, host in enumerate([sso_fqdn] + addresslist):
-        url = "https://%s/simplesamlphp/saml2/idp/certificate" % (host,)
-        link = "addr%d" % (i,)
-        links = {
-            "name": link,
-            "href": url,
-            "label": url,
-        }
-        try:
-            res = requests.get(url, verify=False)  # noqa: S501
-            data = res.content
-        except requests.exceptions.ConnectionError as exc:
-            yield Critical(
-                description=_("Failed to load certificate {{{link}}}: {exc}").format(link=link, exc=exc),
-                links=[links],
-            )
-            continue
-
-        try:
-            certificate = x509.load_pem_x509_certificate(data, backend)
-            MODULE.process("Looking for certificate %s" % (certificate.subject,))
-        except ValueError as exc:
-            yield Critical(
-                description=_("Failed to load certificate {{{link}}}: {exc}").format(link=link, exc=exc),
-                links=[links],
-            )
-            continue
-
-        # compare this with /usr/share/univention-management-console/saml/idp/*.xml
-        for idp in glob.glob(XML):
-            try:
-                tree = parse(idp)
-            except OSError as exc:
-                yield Critical(
-                    description=_("Failed to load certificate {cert!r}: {exc}").format(cert=idp, exc=exc),
-                )
-                continue
-
-            root = tree.getroot()
-            nodes = root.findall(X509CERT)
-            if not nodes:
-                yield Critical(
-                    description=_("Failed to find any certificate in {cert!r}").format(cert=idp),
-                )
-                continue
-
-            for node in nodes:  # FIXME: currently only KeyDescriptor/@use="signing" relevant
-                text = node.text
-                der = b64decode(text)
-                try:
-                    cert = x509.load_der_x509_certificate(der, backend)
-                    MODULE.process("Found certificate %s in %s" % (cert.subject, idp))
-                except ValueError as exc:
-                    yield Critical(
-                        description=_("Failed to load certificate {cert!r}: {exc}").format(cert=idp, exc=exc),
-                    )
-                    continue
-
-                if cert == certificate:
-                    break
-            else:
-                yield Critical(
-                    description=_("The SAML identity provider certificate {cert!r} is missing in {{{link}}}.").format(cert=idp, link=link),
-                    links=[links],
-                )
-
-
 def fix_idp(umc: Instance) -> None:
     MODULE.process("Re-running join-script 92univention-management-console-web-server")
     call(["univention-run-join-scripts", "--force", "--run-scripts", "92univention-management-console-web-server"])
@@ -416,10 +262,10 @@ def test_service_provider_certificate() -> Iterator[Problem]:
             )
 
 
-def dns_link(dn: str) -> Tuple[str, Dict[str, Any]]:
+def dns_link(dn: str) -> tuple[str, dict[str, Any]]:
     """Create UMC UDM link for DN."""
     link = "udm:saml/serviceprovider"
-    umcm: Dict[str, Any] = {
+    umcm: dict[str, Any] = {
         "module": "udm",
         "flavor": "saml/serviceprovider",
         "props": {
@@ -438,7 +284,7 @@ def fix_sp(umc: Instance) -> None:
     return run(umc, rerun=True)
 
 
-actions: Dict[str, Callable[[Instance], None]] = {
+actions: dict[str, Callable[[Instance], None]] = {
     "fix_idp": fix_idp,
     "fix_sp": fix_sp,
 }
