@@ -32,7 +32,8 @@
 
 import itertools as it
 import socket
-from typing import Any, Dict, Iterator, Tuple
+from collections.abc import Iterator
+from typing import Any
 
 import ldap.filter
 
@@ -83,7 +84,7 @@ class CnameAsNameServer(ZoneError):
         return msg.format(ns=self.nameserver.nameserver())
 
 
-class Zone(object):
+class Zone:
     def __init__(self, udm_zone: simpleLdap, domainname: str) -> None:
         self.udm_zone = udm_zone
         self.domainname = domainname
@@ -107,7 +108,7 @@ class Zone(object):
         for nameserver in self.udm_zone.get('nameserver'):
             yield NameServer(self, nameserver)
 
-    def umc_link(self) -> Tuple[str, Dict[str, Any]]:
+    def umc_link(self) -> tuple[str, dict[str, Any]]:
         text = 'udm:dns/dns'
         link = {
             'module': 'udm',
@@ -122,7 +123,7 @@ class Zone(object):
         return (text, link)
 
 
-class NameServer(object):
+class NameServer:
     def __init__(self, zone: Zone, nameserver: str) -> None:
         self.zone = zone
         self._nameserver = nameserver
@@ -142,7 +143,7 @@ class NameServer(object):
         return not self.is_qualified() or \
             self.nameserver().endswith(self.zone.domainname)
 
-    def _generate_splits(self, fqdn: str) -> Iterator[Tuple[str, str]]:
+    def _generate_splits(self, fqdn: str) -> Iterator[tuple[str, str]]:
         zn = fqdn
         while '.' in zn and zn != self.zone.domainname:
             (rdn, zn) = zn.split('.', 1)
@@ -155,7 +156,7 @@ class NameServer(object):
         return '(|{})'.format(''.join(expressions))
 
 
-class UDM(object):
+class UDM:
 
     def __init__(self) -> None:
         univention.admin.modules.update()
