@@ -34,7 +34,8 @@ import ipaddress
 import random
 import socket
 import struct
-from typing import Callable, Iterator, Optional, Tuple, TypeVar
+from collections.abc import Callable, Iterator
+from typing import TypeVar
 
 import dns.exception
 import dns.resolver
@@ -181,7 +182,7 @@ class EmptyResponse(KerberosException):
     pass
 
 
-class Principal(object):
+class Principal:
 
     def __init__(self, name: str, realm: str, princ_type: base.Asn1ItemBase) -> None:
         self.type = princ_type
@@ -196,7 +197,7 @@ class Principal(object):
         return name
 
 
-def seq_set(seq: univ.Sequence, name: str, builder: Optional[Callable] = None) -> base.Asn1ItemBase:
+def seq_set(seq: univ.Sequence, name: str, builder: Callable | None = None) -> base.Asn1ItemBase:
     component = seq.setComponentByName(name).getComponentByName(name)
     if builder is not None:
         seq.setComponentByName(name, builder(component))
@@ -237,7 +238,7 @@ def send_and_receive(kdc: str, port: int, protocol: str, as_req: bytes) -> bytes
     try:
         sock.connect((kdc, port))
         sock.sendall(packed)
-    except (OSError, socket.timeout):
+    except (TimeoutError, OSError):
         sock.close()
         raise ServerUnreachable()
 
@@ -249,7 +250,7 @@ def send_and_receive(kdc: str, port: int, protocol: str, as_req: bytes) -> bytes
     while num_received < 128:
         try:
             (buf, _addr) = sock.recvfrom(128)
-        except (OSError, socket.timeout):
+        except (TimeoutError, OSError):
             buf = b''
         if not buf:
             break
@@ -297,7 +298,7 @@ def probe_kdc(kdc: str, port: int, protocol: str, target_realm: str, user_name:
     return True
 
 
-def resolve_kdc_record(protocol: str, domainname: str) -> Iterator[Tuple[str, int, str]]:
+def resolve_kdc_record(protocol: str, domainname: str) -> Iterator[tuple[str, int, str]]:
     kerberos_dns_fqdn = f'_kerberos._{protocol}.{domainname}'
     try:
         result = dns.resolver.query(kerberos_dns_fqdn, 'SRV')
@@ -344,7 +345,7 @@ def run(_umc_instance: Instance, retest: bool = False) -> None:
             local_included = False
             for interface in configRegistry.get('samba/interfaces', '').split():
                 try:
-                    addr = ipaddress.ip_address(u'%s' % (interface,))
+                    addr = ipaddress.ip_address('%s' % (interface,))
                 except ValueError:
                     local_included |= interface == 'lo'
                 else:
