@@ -36,12 +36,14 @@ import os
 import pwd
 import stat
 from collections import namedtuple
-from typing import Iterator, Tuple
+from collections.abc import Iterator
+from urllib.parse import urlparse
 
 from univention.config_registry import ucr_live as configRegistry
 from univention.lib.i18n import Translation
 from univention.management.console.log import MODULE
 from univention.management.console.modules.diagnostic import Instance, Warning
+from univention.udm import UDM
 
 
 _ = Translation('univention-management-console-module-diagnostic').translate
@@ -62,8 +64,8 @@ class DoesNotExist(CheckError):
 
 
 class OwnerMismatch(CheckError):
-    def __init__(self, filename: str, expected_owner: Tuple[str, str], actual_owner: Tuple[str, str]) -> None:
-        super(OwnerMismatch, self).__init__(filename)
+    def __init__(self, filename: str, expected_owner: tuple[str, str], actual_owner: tuple[str, str]) -> None:
+        super().__init__(filename)
         self.expected_owner = expected_owner
         self.actual_owner = actual_owner
 
@@ -74,7 +76,7 @@ class OwnerMismatch(CheckError):
 
 class PermissionMismatch(CheckError):
     def __init__(self, filename: str, actual_mode: int, expected_mode: int) -> None:
-        super(PermissionMismatch, self).__init__(filename)
+        super().__init__(filename)
         self.actual_mode = actual_mode
         self.expected_mode = expected_mode
 
@@ -83,7 +85,7 @@ class PermissionMismatch(CheckError):
         return msg.format(path=self.filename, actual=self.actual_mode, expected=self.expected_mode)
 
 
-def get_actual_owner(uid: int, gid: int) -> Tuple[str, str]:
+def get_actual_owner(uid: int, gid: int) -> tuple[str, str]:
     try:
         name = pwd.getpwuid(uid).pw_name
     except KeyError:
@@ -120,6 +122,9 @@ def file_and_permission_checks() -> Iterator[CheckError]:
     is_primary = configRegistry.get('server/role') in ('domaincontroller_master', 'domaincontroller_backup')
     is_dc = configRegistry.get('server/role').startswith('domaincontroller_')
     (host, domain) = (configRegistry.get('hostname'), configRegistry.get('domainname'))
+    sso_uri = configRegistry.get('ucs/server/sso/uri', f'https://ucs-sso-ng.{domain.lower()}')
+    sso_domain = urlparse(sso_uri).netloc
+    sso_cert_path = configRegistry.get('keycloak/apache2/ssl/key') or f'/etc/univention/ssl/{sso_domain.lower()}'
 
     cf_type = namedtuple('cf_type', ('path', 'owner', 'group', 'mode', 'must_exist'))
 
@@ -127,18 +132,18 @@ def file_and_permission_checks() -> Iterator[CheckError]:
         cf_type('/etc/ldap/slapd.conf', 'root', 'root', 0o640, must_exist=is_dc),
         cf_type('/etc/ldap.secret', 'root', 'DC Backup Hosts', 0o640, must_exist=is_primary),
         cf_type('/etc/machine.secret', 'root', 'root', 0o600, must_exist=True),
-        cf_type('/etc/pam_ldap.secret', 'root', 'root', 0o600, must_exist=True),
+        cf_type('/etc/pam_ldap.secret', 'root', 'root', 0o600, must_exist=False),
+        cf_type('/etc/libnss-ldap.secret', 'root', 'root', 0o600, must_exist=False),
         cf_type('/etc/idp-ldap-user.secret', 'root', 'DC Backup Hosts', 0o640, must_exist=is_primary),
-        cf_type('/etc/nslcd.conf', 'messagebus', 'root', 0o440, must_exist=True),
+        cf_type('/etc/sssd/sssd.conf', 'root', 'root', 0o600, must_exist=True),
+        cf_type('/var/lib/sss', 'root', 'root', 0o755, must_exist=True),
         cf_type('/var/run/slapd/ldapi', 'root', 'root', 0o700, False),
         cf_type('/etc/univention/ssl', 'root', 'DC Backup Hosts' if is_dc else 'root', 0o755, must_exist=True),
         cf_type('/etc/univention/ssl/openssl.cnf', 'root', 'DC Backup Hosts', 0o660, must_exist=is_primary),
         cf_type('/etc/univention/ssl/password', 'root', 'DC Backup Hosts', 0o660, must_exist=is_primary),
         cf_type('/etc/univention/ssl/ucsCA', 'root', 'DC Backup Hosts' if is_dc else 'root', 0o775 if is_dc else 0o755, must_exist=True),
-        cf_type(f'/etc/univention/ssl/ucs-sso.{domain}', 'root', 'DC Backup Hosts', 0o750, must_exist=is_primary),
         cf_type(f'/etc/univention/ssl/{host}.{domain}', f'{host}$' if is_primary else 'root', 'DC Backup Hosts' if is_dc else 'root', 0o750, must_exist=True),
         cf_type('/var/lib/univention-self-service-passwordreset-umc/memcached.socket', 'self-service-umc', 'nogroup', 0o600, False),
-        cf_type('/var/run/univention-saml/memcached.socket', 'samlcgi', 'nogroup', 0o700, False),
         cf_type('/var/cache/univention-ad-connector', 'root', 'root', 0o755, False),
         cf_type('/var/cache/univention-appcenter', 'root', 'root', 0o755, False),
         cf_type('/var/cache/univention-bind-proxy', 'root', 'root', 0o755, False),
@@ -158,8 +163,16 @@ def file_and_permission_checks() -> Iterator[CheckError]:
         cf_type('/etc/freeradius/ssl', 'root', 'freerad', 0o2755, False),
         cf_type('/usr/share/univention-management-console/oidc/oidc.json', 'root', 'root', 0o600, False),
         cf_type('/etc/umc-oidc.secret', 'root', 'root', 0o600, False),
+        cf_type('/var/lib/samba/ntp_signd', 'root', 'ntpsec', 0o750, False),
     ]
 
+    udm_module = UDM.machine().version(2).get('computers/domaincontroller_backup')
+    backup_fqdns = [obj.props.fqdn for obj in udm_module.search()]
+    if sso_domain != configRegistry.get('ldap/master') and sso_domain not in backup_fqdns:
+        check_file_args.append(
+            cf_type(sso_cert_path, 'root', 'DC Backup Hosts', 0o750, must_exist=is_primary),
+        )
+
     iglob_paths = [
         ('/var/run/univention-management-console/*.socket', ('root', 'root', 0o600, False)),
         ('/var/cache/univention-*', ('root', 'root', 0o700, False)),
