@@ -30,7 +30,7 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from typing import Dict, Iterator, List, Tuple
+from collections.abc import Iterator
 
 import ldap
 
@@ -71,7 +71,7 @@ class SIDNotFound(CheckError):
 
 class SIDMismatch(CheckError):
     def __init__(self, sid: str, actual_sid: str, expected_name: str) -> None:
-        super(SIDMismatch, self).__init__(sid, expected_name)
+        super().__init__(sid, expected_name)
         self.actual_sid = actual_sid
 
     def __str__(self) -> str:
@@ -81,7 +81,7 @@ class SIDMismatch(CheckError):
 
 class NameMismatch(CheckError):
     def __init__(self, sid: str, expected_name: str, actual_name: str) -> None:
-        super(NameMismatch, self).__init__(sid, expected_name)
+        super().__init__(sid, expected_name)
         self.actual_name = actual_name
 
     def __str__(self) -> str:
@@ -89,11 +89,11 @@ class NameMismatch(CheckError):
         return msg.format(sid=self.sid, actual=self.actual_name, expected=self.expected_name)
 
 
-class LDAPConnection(object):
+class LDAPConnection:
     def __init__(self) -> None:
         self._connection = univention.uldap.getMachineConnection()
 
-    def search(self, expression: str, attr: List[str] = []) -> Iterator[Tuple[str, Dict[str, List[bytes]]]]:
+    def search(self, expression: str, attr: list[str] = []) -> Iterator[tuple[str, dict[str, list[bytes]]]]:
         for (dn, attrs) in self._connection.search(expression, attr=attr):
             if dn is not None:
                 yield (dn, attrs)
@@ -121,7 +121,7 @@ class LDAPConnection(object):
         raise KeyError(name)
 
 
-def all_sids_and_names(domain_sid: str) -> Iterator[Tuple[str, str]]:
+def all_sids_and_names(domain_sid: str) -> Iterator[tuple[str, str]]:
     for (sid, name) in s4.well_known_sids.items():
         if name not in NON_EXISTENT_SIDS:
             yield (sid, name)
