@@ -31,7 +31,7 @@
 # <https://www.gnu.org/licenses/>.
 
 import re
-from typing import Iterator
+from collections.abc import Iterator
 
 import univention.uldap
 from univention.lib.i18n import Translation
