@@ -33,7 +33,7 @@
 import glob
 import re
 import subprocess
-from typing import Iterator
+from collections.abc import Iterator
 
 from univention.lib.i18n import Translation
 from univention.management.console.modules.diagnostic import MODULE, Instance, Warning
@@ -68,7 +68,7 @@ actions = {
 
 class TracebackFound(Exception):
     def __init__(self, path: str, exception: str) -> None:
-        super(TracebackFound, self).__init__(path, exception)
+        super().__init__(path, exception)
         self.path = path
         self.exception = exception
 
