@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Copyright 2023-2024 Univention GmbH
 #
@@ -31,7 +30,6 @@
 """Check Listener queues of installed apps for unprocessed files."""
 
 from pathlib import Path
-from typing import List
 
 from univention.lib.i18n import Translation
 from univention.management.console.modules.diagnostic import Instance, Warning
@@ -53,7 +51,7 @@ LISTENER_DIR = Path('/var/lib/univention-appcenter/listener/')
 
 
 def run(_umc_instance: Instance) -> None:
-    error_descriptions: List[str] = []
+    error_descriptions: list[str] = []
 
     for app_path in APP_DIR.glob("*"):
         converter_dir = LISTENER_DIR / app_path.name
